<?php

/*
Plugin Name: Volunteer
Description: Manage Event Volunteers
Author: Philip Wittamore
Author URI: http://www.pawdata.com/
*/

# ini set
#ini_set('output_buffering','On');
#ini_set('display_errors', '0');
ini_set('error_reporting',E_ALL|E_STRICT);
ini_set('display_errors', '1');

# check volunteer data folder
if(!is_dir(GSDATAOTHERPATH.'volunteer')){
  @mkdir(GSDATAOTHERPATH.'volunteer', 0755);  
}

# include phpmailer
require GSPLUGINPATH.'volunteer/class/PHPMailer/class.phpmailer.php';

# paths
$thisfile    = basename(__FILE__, '.php');
$vl_settings = GSDATAOTHERPATH.'volunteer/settings.xml';
$website     = GSDATAOTHERPATH.'website.xml';

# retrieve volunteer admin email address
if (file_exists($vl_settings)) {
    $item = getXML($vl_settings);
    $admin_email = $item->admin_email;
}

if (file_exists($website)) {
    $item = getXML($website);
    if(isset($item->SITEURL)) $SITEURL = $item->SITEURL;
}                        

# add in this plugin's language file
i18n_merge($thisfile) || i18n_merge($thisfile, 'en_US');

# register plugin
register_plugin(
	$thisfile,            //Plugin id
	'Volunteer', 	      //Plugin name
	'0.4.1',              //Plugin version
	'Philip Wittamore',   //Plugin author
	'http://volunteer.pawdata.com/', //author website
	'Volunteer Manager',  //Plugin description
	'Pages',              //page type - on which admin tab to display
	'vl_admin'            //main function (administration)
);

# create db if it doesn't exist
vl_createdb();

# add css and session
add_action('index-pretemplate','vl_pretemplate',array());

# add to page header
add_action('theme-header','vl_themeheader',array());

# add a link in the admin tab 'pages'
add_action('pages-sidebar','createSideMenu',array($thisfile,'Volunteer Manager'));

# activate filter 
add_filter('content','vl_inject_content');

function vl_themeheader(){
}

# add pretemplate
function vl_pretemplate() {

   global $SITEURL;

    if (!isset($_SESSION)) {
        @session_start();
    }

    register_style('volunteer-css',$SITEURL.'plugins/volunteer/css/volunteer.css','1','screen');
    register_style('jquery-ui.css','//ajax.googleapis.com/ajax/libs/jqueryui/1/themes/smoothness/jquery-ui.css','1',FALSE);
    
    queue_style('jquery-ui.css', GSFRONT);
    queue_style('volunteer-css', GSFRONT);

    register_script('jquery', '//code.jquery.com/jquery-latest.min.js','1',FALSE);
    register_script('jquery-ui', '//ajax.googleapis.com/ajax/libs/jqueryui/1/jquery-ui.min.js','1',FALSE);
    register_script('dp.js', $SITEURL.'plugins/volunteer/js/dp.js','1', FALSE);

    queue_script('jquery', GSFRONT);
    queue_script('jquery-ui', GSFRONT);
    queue_script('dp.js', GSFRONT);

    
    /*
    TODO
        if (isset($_SESSION['last_activity'])) {
        if (time() - $_SESSION['last_activity'] > 1800) {
            // last request was more than 30 minutes ago
            connect_db();
            $sql="UPDATE volunteers SET connected = '0' WHERE email = '".$_SESSION['vl_user']."'";
            $result = mysql_query( $sql ) or die("ERROR: Unable to query database");
            @session_unset();     // unset $_SESSION variable for the run-time 
            @session_destroy();   // destroy session data in storage
            header("Location: ".$_SERVER['REQUEST_URI']);
        } else if (time() - $_SESSION['last_activity'] > 60) {
            $_SESSION['last_activity'] = time(); // update last activity time stamp
        }
    }
    */
    
}
                
# admin page function
function vl_admin() {

    global $vl_settings;
    $error=null;
    $admin_email=null;

    echo '<h2>Volunteer Manager</h2>';
    echo '<h3>Settings</h3>';

    if (file_exists($vl_settings)) {
        $settings_data = getXML($vl_settings);
        if(isset($settings_data->admin_email)) $admin_email = $settings_data->admin_email;
    }
    
    if (isset($_POST['admin_submit'])) {
                                                          
        $email = mailclean($_POST['admin_email']);
        if ($email) {
            $xml = @new SimpleXMLElement('<item></item>');
            $xml->addChild('admin_email', $email);
            $xml->asXML($vl_settings);
            $settings_data = getXML($vl_settings);
        }else{
            echo '<span style="color:red;">Incorrect admin email address.</span>';
        }
    }

    echo '<form method="post" id="settings_data" action="'.$_SERVER['REQUEST_URI'].'"><table>';
    if(isset($settings_data->admin_email)) $admin_email = $settings_data->admin_email;
    echo '<tr><td>Admin email address:</td><td><input type="text" name="admin_email" id="admin_email" value="'.$admin_email.'" /><td></tr>';
    echo '<tr><td><input class="submit" type="submit" value="save" name="admin_submit" /></td></tr></table></form>';

}

function vl_inject_content($content){
    
    $code=null;
    global $vl_settings;
 
    try { 
        $pdo = new PDO('sqlite:'.GSDATAOTHERPATH.'volunteer/volunteer.db');
        $pdo->setAttribute(PDO::ATTR_ERRMODE,PDO::ERRMODE_EXCEPTION);
    }  
    catch(PDOException $e) {
        $code = $e->getMessage();  
    }  

    if (preg_match('#\[vl_user\]#', $content)) {
        if (isset($_SESSION['vl_user'])) {
            $code .= '<h3>'.$_SESSION['vl_user'].'</h3>';
        }
        $content = preg_replace('#\[vl_user\]#', $code, $content);
        unset($code);
    }
                    
    
    /**********************
    * User login
    *
    */
    
    if (preg_match('#\[vl_connect\]#', $content)) {
        $code=null;
        // disconnect
        if (isset($_SESSION['vl_user'])) {
            if (isset($_POST['disconnect_submit'])) {
                $pdo->exec($sql="UPDATE volunteers SET connected = '0' WHERE email = '".$_SESSION['vl_user']."'");
                unset($_SESSION['vl_user']);
                $pdo=null;
                header("Location: ".$_SERVER['REQUEST_URI']);
                exit();
            }else{
                $code .= '<div id="vl_login"><h3>Disconnect</h3>';
                $code .= '<form method="post" id="login" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                $code .= '<tr><td class="vl_col1">&nbsp;</td>';
                $code .= '<td><input class="submit" type="submit" value="Disconnect" name="disconnect_submit" /></td></tr>';
                $code .= '</table></form></div>';
            }
        }else{
            // connect
            if (isset($_POST['login_submit'])) {

                if (isset($_POST['iforgot_request'])) {
                  //if ($_POST['iforgot_request'] == 1) {
                    if (!isset($_POST['login_email'])) {
                          $_SESSION['connfail'] = 'ERROR: missing email address';
                    }else{

                        // send password reset and display form
                        $sql="SELECT COUNT(*) FROM volunteers WHERE email = '".$_POST['login_email']."'";
                        $result = $pdo->query($sql);
                        $row = $result->fetch(PDO::FETCH_NUM);
                        $count = $row[0];
                        if ($count) {
                            // no need to test rcpt addr as already tested at registration
                            $_SESSION['newpass'] = vl_genpassword(8);
                            $settings_data = getXML($vl_settings);
                            if(isset($settings_data->admin_email)) $admin_email = $settings_data->admin_email;
                            $message  = "A password reset has been requested for your account.\r\n";
                            $message .= "If you wish to change your password, please enter the password below\r\n\r\n";
                            $message .= $_SESSION['newpass']."\r\n\r\nBest regards, Your Volunteer Admin";
                            $mail = new PHPMailer;
                            $mail->Sender = $admin_email;
                            $mail->From   = $admin_email;
                            $mail->FromName = 'Admin';
                            $mail->addAddress($_POST['login_email']);
                            $mail->Subject = 'Volunteer: Password Reset Request';
                            $mail->Body    = $message;
                            if(!$mail->send()) {
                                $code .= 'Message could not be sent.';
                                $code .= 'Mailer Error: ' . $mail->ErrorInfo;
                            }else{
                                $code  = '<div id="vl_login"><h3>Change Password</h3>';
                                $code .= '<p>A new password has been sent to <span style="color:blue;">';
                                $code .= $_POST['login_email'].'</span></p><p>Please enter it below:</p>';
                                $code .= '<form method="post" id="chpw" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                                $code .= '<tr><td class="vl_col1">Password:</td><td><input type="password" name="iforgot_password" /></td></tr>';
                                $code .= '<tr><td></td><td><input class="submit" type="submit" value="Change Password" name="submit" />';
                                $code .= '</table><input type="hidden" name="iforgot_email" value="'.$_POST['login_email'].'" /></form></div>';
                            }
                        }else{
                            $_SESSION['connfail'] = 'ERROR: Cannot change password, account unknown.';
                            $pdo=null;
                            header("Location: ".$_SERVER['REQUEST_URI']);
                            exit();
                        }
                    }
                }else{
                    // log in
                    $sql = "SELECT COUNT(*) FROM volunteers WHERE email = '".$_POST['login_email']."' AND password = '".md5($_POST['login_password'])."'";
                    $result = $pdo->query($sql);
                    $row = $result->fetch(PDO::FETCH_NUM);
                    $count = $row[0];
                    if ($count) {
                        $pdo->query("UPDATE volunteers SET connected = '1' WHERE email = '".$_POST['login_email']."'");
                        $pdo->exec($sql);
                        $sql = "UPDATE volunteers SET lastaccess=datetime()";
                        $pdo->exec($sql);
                        $_SESSION['vl_user'] = $_POST['login_email'];
                    }else{
                        $_SESSION['connfail'] = 'ERROR: Connection failed: bad login/password.';
                    }
                    $pdo=null;
                                
                    
                    header("Location: ".$_SERVER['REQUEST_URI']);
                    exit();
                }
            }
            if ( isset($_POST['iforgot_password']) && isset($_POST['iforgot_email']) ) {
                // reset password
                if ($_SESSION['newpass'] == $_POST['iforgot_password']) {
                    $pdo->exec("UPDATE volunteers SET password = '".md5($_POST['iforgot_password'])."' WHERE email = '".$_POST['iforgot_email']."'");
                    $_SESSION['connfail'] = 'Password changed successfully.';
                }else{
                    $_SESSION['connfail'] = 'ERROR: Password unchanged, check failed.';
                }
                unset ($_SESSION['newpass']);
                unset ($_POST['iforgot_password']);
                unset ($_POST['iforgot_email']);
                $pdo=null;
                header("Location: ".$_SERVER['REQUEST_URI']);
                exit();
            }
            if (!($_SERVER['REQUEST_METHOD'] == "POST")) {
                # display login form
                if (isset($_SESSION['connfail'])) {
                    $code  = '<p><span style="color:red;">'.$_SESSION['connfail'].'</span></p>';
                    unset($_SESSION['connfail']);
                }else{
                    $code=null;
                }
                $code .= '<div id="vl_login"><h3>Connect</h3>';
                $code .= '<form method="post" id="login" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                $code .= '<tr><td class="vl_col1">Email:</td><td><input type="text" name="login_email" /></td></tr>';
                $code .= '<tr><td>Password:</td><td><input type="password" name="login_password" /></td></tr>';
                $code .= '<tr><td>Reset Password:</td><td><input type="checkbox" name="iforgot_request" value="1" /></td></tr>';
                $code .= '<tr><td></td><td><input class="submit" type="submit" value="Connect" name="login_submit" />';
                $code .= '</td></tr></table></form></div>';
            }
        }
        $content = preg_replace('#\[vl_connect\]#', $code, $content);
        unset($code);
    }


    /**********************
    * register page
    *
    */
    
    $code=null;
    if (preg_match('#\[vl_register\]#', $content)) {
      if ( !isset($_SESSION['vl_user']) ) {
        if (isset($_POST['register_submit'])) {
            $email = mailclean($_POST['reg_email']);
            
            if ($email) {
                $password = vl_genpassword(8);
                # check if email exists
                $sql="SELECT COUNT(*) FROM volunteers WHERE email = '".$email."'";
                $result = $pdo->query($sql);   
                $row = $result->fetch(PDO::FETCH_NUM);
                $count = $row[0];
                if ($count) {
                    $code .= '<p>'.$email.' already exists.</p>';
                    $code .= '<p><a href="'.$_SERVER['REQUEST_URI'].'">Go Back</a></p>';
                }else{                            
                    $sql = "INSERT INTO volunteers (email,password,fname,lname) VALUES ('".
                         $email."','".md5($password)."','".$_POST['reg_fname']."','".$_POST['reg_lname']."')";
                    $pdo->exec($sql);
                    
                    $settings_data = getXML($vl_settings);
                    if(isset($settings_data->admin_email)) $admin_email = $settings_data->admin_email;
                    $message  = "Thankyou for registering!\r\nYour password is: ". $password;
                    $mail = new PHPMailer;
                    $mail->Sender = $admin_email;
                    $mail->From   = $admin_email;
                    $mail->FromName = 'Admin';
                    $mail->addAddress($email);
                    $mail->Subject = 'Volunteer: Your Registration';
                    $mail->Body    = $message;
                    if(!$mail->send()) {
                        $code .= 'Message could not be sent.';   
                        $code .= 'Mailer Error: ' . $mail->ErrorInfo;
                    }else{
                        $code .= '<h3>Registration sucessful!</h3><p>Your password has been sent to '.$email.'</p>';
                    }
                    $code .= '<p><a href="'.$_SERVER['REQUEST_URI'].'">Go Back</a></p>';
                    $pdo=null;
                }
                
            }else{
                $code .= '<p><span style="color:red;">ERROR: incorrect email address</span></p>';
                $code .= '<p><a href="'.$_SERVER['REQUEST_URI'].'">Back</a></p>';
            }    
        }else{    
            if (!($_SERVER['REQUEST_METHOD'] == "POST")) {
                # define register form
                $code  = '<div id="vl_register"><h3>Register a new volunteer</h3>'; 
                $code .= '<form method="post" id="register_volunteer" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                $code .= '<tr><td class="vl_col1">Email:</td><td><input type="text" name="reg_email" /></td></tr>';
                $code .= '<tr><td>First Name:</td><td><input type="text" name="reg_fname" /></td></tr>';
                $code .= '<tr><td>Last Name:</td><td><input type="text" name="reg_lname" /></td></tr>';
                $code .= '<tr><td></td><td>';
                $code .= '<input class="submit" type="submit" value="Register" name="register_submit" /></td></tr>';
                $code .= '</table></form></div>';
            }
        }
      }    
        $content = preg_replace('#\[vl_register(.*)\]#', $code, $content); 
        unset($code);
    }


    /**********************
    * Edit user profile
    *
    */
    
    if (preg_match('#\[vl_profile\]#', $content)) {
        $code=null;
        if(isset($_SESSION['vl_user'])) {
            if (isset($_POST['profile_submit'])) {
                $sql = "UPDATE volunteers SET ". 
                          "fname='".htmlentities($_POST['profile_fname'],ENT_QUOTES).
                        "',lname='".htmlentities($_POST['profile_lname'],ENT_QUOTES).
                        "',address='".htmlentities($_POST['profile_address'],ENT_QUOTES).
                        "',city='".htmlentities($_POST['profile_city'],ENT_QUOTES).
                        "',zip='".htmlentities($_POST['profile_zip'],ENT_QUOTES).
                        "',country='".htmlentities($_POST['profile_country'],ENT_QUOTES).
                        "',tel_home='".htmlentities($_POST['profile_tel_home'],ENT_QUOTES).
                        "',tel_work='".htmlentities($_POST['profile_tel_work'],ENT_QUOTES).
                        "',mobile1='".htmlentities($_POST['profile_mobile1'],ENT_QUOTES).
                        "',mobile2='".htmlentities($_POST['profile_mobile2'],ENT_QUOTES).
                        "',comments='".htmlentities($_POST['profile_comments'],ENT_QUOTES).
                        "' WHERE email = '".$_SESSION['vl_user']."'";
                $pdo->exec($sql);
                $pdo=null;
                header("Location: ".$_SERVER['REQUEST_URI']);
                exit();            
            }
            $sql = "SELECT * FROM volunteers WHERE email = '".$_SESSION['vl_user']."'";
            $result = $pdo->query($sql);
            $row = $result->fetch(PDO::FETCH_ASSOC);

            $code  = '<div id="vl_profile"><h3>Edit Profile</h3><form method="post" id="profile" action="'.$_SERVER['REQUEST_URI'].'"><table>';
            $code .= '<tr><td class="vl_col1">First Name:</td><td><input type="text" name="profile_fname" value="'.$row['fname'].'" /></td></tr>';
            $code .= '<tr><td>Last Name:</td><td><input type="text" name="profile_lname" value="'.$row['lname'].'" /></td></tr>';
            $code .= '<tr><td>Address:</td><td><input type="text" name="profile_address" value="'.$row['address'].'" /></td></tr>';
            $code .= '<tr><td>City:</td><td><input type="text" name="profile_city" value="'.$row['city'].'" /></td></tr>';
            $code .= '<tr><td>Zip:</td><td><input type="text" name="profile_zip" value="'.$row['zip'].'" /></td></tr>';
            $code .= '<tr><td>Country:</td><td><input type="text" name="profile_country" value="'.$row['country'].'" /></td></tr>';
            $code .= '<tr><td>Tel. Home:</td><td><input type="text" name="profile_tel_home" value="'.$row['tel_home'].'" /></td></tr>';
            $code .= '<tr><td>Tel. Work:</td><td><input type="text" name="profile_tel_work" value="'.$row['tel_work'].'" /></td></tr>';
            $code .= '<tr><td>Mobile 1:</td><td><input type="text" name="profile_mobile1" value="'.$row['mobile1'].'" /></td></tr>';
            $code .= '<tr><td>Mobile 2:</td><td><input type="text" name="profile_mobile2" value="'.$row['mobile2'].'" /></td></tr>';
            $code .= '<tr><td>Comments:</td><td><textarea rows="5" name="profile_comments">'.$row['comments'].'</textarea></td></tr>';
            $code .= '<tr><td>Last Access:</td><td>'.$row['lastaccess'].'</td></tr>';
            $code .= '<tr><td>Last Subscription:</td><td>'.$row['lastsubscribe'].'</td></tr>';
            $code .= '<tr><td></td><td><input class="submit" type="submit" value="Save" name="profile_submit" /></td></tr>';
            $code .= '</table></form></div>';
        }
        $content = preg_replace('#\[vl_profile(.*)\]#', $code, $content);
        unset($code);
    }


    /**********************
    * events
    *
    */

    if (preg_match('#\[vl_events\]#', $content)) {
    
        $settings_data = getXML($vl_settings);
        if(isset($settings_data->admin_email)) $admin_email = $settings_data->admin_email;                           
    
        if (isset($_SESSION['vl_user'])) {
            $code = null;
            // user tasks


            if (isset($_POST['ev_volunteer'])) {
                $sql = "DELETE FROM subscriptions WHERE (email='".$_SESSION['vl_user']."') AND (event_id='".$_POST['event_id']."')";
                $pdo->exec($sql);
                $sql = "INSERT INTO subscriptions ('email','event_id') VALUES ('".$_SESSION['vl_user']."','".$_POST['event_id']."')";
                $pdo->exec($sql);
                $sql = "UPDATE volunteers SET lastsubscribe=datetime()";
                $pdo->exec($sql);
            }
                                    
            if (isset($_POST['ev_del_vol_user'])) {
                $sql = "DELETE FROM subscriptions WHERE (event_id = '".$_POST['event_id']."') AND (email = '".$_SESSION['vl_user']."')";
                $pdo->exec($sql);
            }
            
            if (isset($_POST['ev_view'])) {
                $sql = "SELECT * from events WHERE event_id = '".$_POST['event_id']."'";
                $result = $pdo->query($sql);
                $row = $result->fetch(PDO::FETCH_ASSOC);
             
                $code = null;
                $code .= '<div id="vl_event"><h3>View Event</h3>';
                $code .= '<form method="post" id="create_event" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                $code .= '<tr><td>Start Date:</td><td><input type="text" name="ce_start" size="10" value="'.$row['start_date'].'" readonly /></td></tr>';
                $code .= '<tr><td>End Date:</td><td><input type="text" name="ce_end" size="10" value="'.$row['end_date'].'" readonly /></td></tr>';
                $code .= '<tr><td>Name:</td><td><input type="text" size="40" name="ce_name" value="'.$row['name'].'" readonly /></td></tr>';
                $code .= '<tr><td>Details:</td><td><textarea cols="40" rows="5" name="ce_details" readonly >'.$row['details'].'</textarea></td></tr>';
                $code .= '<tr><td colspan="2"><input type="hidden" name="event_id" value="'.$row['event_id'].'" />';
                $code .= '<input type="hidden" name="ev_view" value="1" />';
                $code .= '<input type="submit" name="ev_volunteer" value="Volunteer!" />&nbsp;';
                $code .= '<input type="submit" name="ev_del_vol_user" value="Un-Volunteer" />';
                $code .= '<a href="'.$_SERVER['REQUEST_URI'].'"><input type="button" name="cancel" value="Quit" /></a>&nbsp;';
                $code .= '<td></td><td></td></tr>';
                $code .= '</table></form><p>&nbsp;</p>';
                $code .= '<h3>Volunteers for this event</h3>';
                $result = $pdo->query("SELECT * FROM subscriptions WHERE event_id='".$_POST['event_id']."'");
                if (count($result)) {
                    $code .= '<table>';
                    foreach($result as $row) {
                        $code .= '<tr><td>'.$row['email'].'</td></tr>';
                    }
                    $code .= '</table></div>';
                }
                                                                                                
            }
            
            if (empty($_POST) || isset($_POST['page'])) { 
            
                #list events
                if ( isset($admin_email) && ($admin_email == $_SESSION['vl_user']) ) {
                    $code .= '<form method="post" id="create_event" action="'.$_SERVER['REQUEST_URI'].'">';
                    $code .= '<input type="submit" name="create_event" value="Create New Event" /></form><br />';
                }
                
                $rowsPerPage = 50;                  
                if (isset($_POST['page'])) $pageNum = $_POST['page'];                    
                if (!isset($pageNum)) $pageNum = 1;
                $offset = ($pageNum - 1) * $rowsPerPage;
                
                $sql="SELECT COUNT(*) FROM events";
                $result = $pdo->query($sql);
                $row = $result->fetch(PDO::FETCH_NUM);
                $lastpage = ($row[0] / $rowsPerPage);

                $code .= '<h3>List of events</h3>';                
                $result = $pdo->query("SELECT * FROM events ORDER BY start_date DESC LIMIT '".$offset."', '".$rowsPerPage."'");
                if (count($result)) {
                    $code .= '<table><tr id="vl_ev_nav_bar"><td id="vl_ev_nav_left">';
                    if ($pageNum>1) {
                        $code .= '<form method="post" id="prevpage" action="'.$_SERVER['REQUEST_URI'].'">';
                        $code .= '<input type="hidden" name="page" value="'.($pageNum - 1).'"/>';
                        $code .= '<input type="submit" value="<" /></form>';
                    }
                        $code .= '</td><td id="vl_ev_nav_center">Page No.'.$pageNum.'</td><td id="vl_ev_nav_right">';
                    if ($pageNum < $lastpage) {
                        $code .= '<form method="post" id="nextpage" action="'.$_SERVER['REQUEST_URI'].'">';
                        $code .= '<input type="hidden" name="page" value="'.($pageNum + 1).'"/>';
                        $code .= '<input type="submit" value=">" /></form>';
                    }
                    $code .= '</td></tr></table><table>';
                    foreach($result as $row) {
                        $code .= '<tr><td style="width:20%">'.$row['start_date'].
                             '</td><td>'.$row['name'].
                             '</td><td style="width:20%;text-align:right;"><form method="post" id="event_list" action="'.$_SERVER['REQUEST_URI'].'">'.
                             '<input type="hidden" name="event_id" value="'.$row['event_id'].'" />';
                        if ( isset($admin_email) && ($admin_email == $_SESSION['vl_user']) ) { 
                            $code .= '<input type="submit" name="ev_edit" value="Edit" />';
                        }else{
                        $code .= '<input type="submit" name="ev_view" value="View" />';
                        }
                        $code .= '</form></td></tr>';
                    }
                    $code .= '</table>';
                }
            }
            
            
            
            
            
            /*** admin tasks ***/
               
            if ( isset($admin_email) && ($admin_email == $_SESSION['vl_user']) ) {
            
                if (isset($_POST['ev_create'])) {
                    $sql = "INSERT INTO events (name,start_date,end_date,details) VALUES (".
                           "'".htmlentities($_POST['ce_name'],ENT_QUOTES).
                           "','".$_POST['ce_start'].
                           "','".$_POST['ce_end'].
                           "','".htmlentities($_POST['ce_details'],ENT_QUOTES).
                           "')";
                    $pdo->exec($sql);
                    $pdo=null;
                    unset($_POST);
                    header("Location: ".$_SERVER['REQUEST_URI']);
                    exit();
                }

                if (isset($_POST['ev_mod'])) {
                       $sql = "UPDATE events SET ".
                              "name='".htmlentities($_POST['ce_name'],ENT_QUOTES).
                            "',start_date='".$_POST['ce_start'].
                            "',end_date='".$_POST['ce_end'].
                            "',details='".htmlentities($_POST['ce_details'],ENT_QUOTES).
                            "' WHERE event_id = '".$_POST['event_id']."'";
                       $pdo->exec($sql);
                       $pdo=null;
                       unset($_POST);
                                   
                       
                       header("Location: ".$_SERVER['REQUEST_URI']);
                       exit();
                }
              
                if (isset($_POST['ev_delete'])) {
                       $sql = "DELETE FROM events WHERE event_id = '".$_POST['event_id']."'";
                       $pdo->query($sql);
                       $pdo=null;
                       unset($_POST);
                       header("Location: ".$_SERVER['REQUEST_URI']);
                       exit();
                }
                
                if (isset($_POST['ev_del_vol'])) {
                    $sql = "DELETE FROM subscriptions WHERE (event_id = '".$_POST['event_id']."') AND (email = '".$_POST['event_vol']."')";
                    $pdo->exec($sql); 
                }
            
               if (isset($_POST['ev_edit'])) {
                   $sql = "SELECT * from events WHERE event_id = '".$_POST['event_id']."'";
                   $result = $pdo->query($sql);
                   $row = $result->fetch(PDO::FETCH_ASSOC);               
                   $code = null;
                   $code .= '<div id="vl_event"><h3>Edit Event</h3>';
                   $code .= '<form method="post" id="create_event" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                   $code .= '<tr><td>Start Date:</td><td><input type="text" id="dpsta" name="ce_start" size="10" value="'.$row['start_date'].'" readonly /></td></tr>';
                   $code .= '<tr><td>End Date:</td><td><input type="text" id="dpend" name="ce_end" size="10" value="'.$row['end_date'].'" readonly /></td></tr>';
                   $code .= '<tr><td>Name:</td><td><input type="text" size="40" name="ce_name" value="'.$row['name'].'" /></td></tr>';
                   $code .= '<tr><td>Details:</td><td><textarea cols="40" rows="5" name="ce_details">'.$row['details'].'</textarea></td></tr>';
                   $code .= '<tr><td colspan="2"><input type="hidden" name="event_id" value="'.$row['event_id'].'" />';
                   $code .= '<input type="hidden" name="ev_edit" value="1" />';
                   $code .= '<input type="submit" name="ev_volunteer" value="Volunteer!" />&nbsp;';
                   $code .= '<input type="submit" name="ev_delete" value="Delete" />&nbsp;';
                   $code .= '<input type="submit" name="ev_mod" value="Save" />&nbsp;';
                   $code .= '<a href="'.$_SERVER['REQUEST_URI'].'"><input type="button" name="cancel" value="Quit" /></a>&nbsp;';
                   $code .= '<td></td><td></td></tr></table></form>';
                   $code .= '<p>&nbsp;</p>';
                   $code .= '<h3>Volunteers for this event</h3>';
                   $result = $pdo->query("SELECT * FROM subscriptions WHERE event_id='".$_POST['event_id']."'");
                   if (count($result)) {
                       $code .= '<table>';
                       foreach($result as $row) {
                           $code .= '<tr><td>'.$row['email'].'</td><td>';
                           $code .= '<form method="post" id="delete_event_volunteer" action="'.$_SERVER['REQUEST_URI'].'">';
                           $code .= '<input type="hidden" name="event_id" value="'.$_POST['event_id'].'" />';
                           $code .= '<input type="hidden" name="ev_edit" value="1" />';
                           $code .= '<input type="hidden" name="event_vol" value="'.$row['email'].'" />';
                           $code .= '<input type="submit" name="ev_del_vol" value="Remove">';
                           $code .= '</form></td></tr>';
                       }
                       $code .= '</table></div>';
                   }
                }
            
                if (isset($_POST['create_event'])) {
                $code = null;
                $code .= '<div id="vl_event"><h3>Create Event</h3>';
                $code .= '<form method="post" id="create_event" action="'.$_SERVER['REQUEST_URI'].'"><table>';
                $code .= '<tr><td>Start Date:</td><td><input type="text" id="dpsta" name="ce_start" size="10" value="" readonly /></td></tr>';
                $code .= '<tr><td>End Date:</td><td><input type="text" id="dpend" name="ce_end" size="10" value="" readonly /></td></tr>';
                $code .= '<tr><td>Name:</td><td><input type="text" size="40" name="ce_name" value="" /></td></tr>';
                $code .= '<tr><td>Details:</td><td><textarea cols="40" rows="5" name="ce_details"> </textarea></td></tr>';
                $code .= '<tr><td colspan="2">';
                $code .= '<a href="'.$_SERVER['REQUEST_URI'].'"><input type="button" name="cancel" value="Cancel" /></a>&nbsp;';
                $code .= '<input type="submit" name="ev_create" value="Save" /><td></td><td></td></tr>';
                $code .= '</table></form></div>';
                }
            }
            


        }else{
            $code = '<p>Please connect to view the list of events';
        }
        
        $content = preg_replace('#\[vl_events\]#', $code, $content);
        unset($code);
        
    }

//////////////

    # return the modified content
    $pdo = null;
    return $content;
}



// functions
# show the logged in user in the sidebar
function vl_displayuser() {

    if (isset($_SESSION['vl_user'])) {
        echo "<h2>Connected Volunteer</h2><p>".$_SESSION['vl_user']."</p>";
    }

}


function vl_createdb() {

    $pdo = new PDO('sqlite:'.GSDATAOTHERPATH.'volunteer/volunteer.db');
    $pdo->setAttribute(PDO::ATTR_ERRMODE,PDO::ERRMODE_EXCEPTION);
    $sql='CREATE TABLE IF NOT EXISTS volunteers ('.
        'email VARCHAR(40),'. 
        'password VARCHAR(40),'.
        'connected BOOLEAN,'.
        'lastaccess DATETIME,'.
        'lastsubscribe DATETIME,'.
        'role VARCHAR(20),'.
        'fname VARCHAR(40),'.
        'lname VARCHAR(40),'.
        'address VARCHAR(255),'.
        'city VARCHAR(40),'.
        'zip VARCHAR(10),'.
        'country VARCHAR(20),'.
        'tel_work VARCHAR(40),'.
        'tel_home VARCHAR(40),'.
        'mobile1 VARCHAR(40),'.
        'mobile2 VARCHAR(40),'.
        'comments TEXT'.
    ')';
    $pdo->exec($sql);
    
    $sql='CREATE UNIQUE INDEX IF NOT EXISTS email_index ON volunteers(email)';
    $pdo->exec($sql);
    
    $sql='CREATE TABLE IF NOT EXISTS events ('.
        'event_id INTEGER PRIMARY KEY,'.
        'name VARCHAR(40),'.
        'start_date DATE,'.
        'end_date DATE,'.
        'details TEXT'.
    ')';
    $pdo->exec($sql);
    
    $sql='CREATE UNIQUE INDEX IF NOT EXISTS event_index ON events(event_id)';
    $pdo->exec($sql);

    $sql='CREATE TABLE IF NOT EXISTS subscriptions (email VARCHAR(40), event_id INTEGER)';
    $pdo->exec($sql);
    
    
    $pdo = null;
    
}

function vl_genpassword($len) {
    $pass = '';
    $lchar = 0;
    $char = 0;
    for($i = 0; $i < $len; $i++) {
        while($char == $lchar) {
            $char = rand(48, 109);
            if($char > 57) $char += 7;
            if($char > 90) $char += 6;
        }
        $pass .= chr($char);
        $lchar = $char;
    }
    return $pass;
}

function mailclean($email) {
    $email = strip_tags($email);
    $email = str_replace('"',"", $email);
    $email = str_replace("'","", $email);
    $email = str_replace(",","", $email);
    $email = filter_var($email,FILTER_SANITIZE_EMAIL);
    $email = filter_var($email, FILTER_VALIDATE_EMAIL);
    return $email;
}                                                                        


?>